@@ -1,3 +1,6 @@
+import io
+from importlib import resources
+
 import numpy as np
 import pandas as pd
 
@@ -8,9 +11,12 @@ def load_ffme_returns(cols=None):
     """
     Load the Fama-French Dataset for the returns of the Top and Bottom Deciles by MarketCap
     """
+    with resources.open_binary("tests.data", Params.DATA_FFME_PATH) as file:
+        file = file.read()
+        file = io.BytesIO(file)
     if cols is None:
         cols = ["Lo 10", "Hi 10"]
-    df = pd.read_csv(Params.DATA_FFME_PATH, index_col=0, na_values=-99.99)
+    df = pd.read_csv(file, index_col=0, na_values=-99.99)
     df.index = pd.to_datetime(df.index, format="%Y%m").to_period("M")
     df /= 100
     df = df[cols]
@@ -22,7 +28,10 @@ def load_hfi_returns():
     """
     Load and format the EDHEC Hedge Fund Index Returns
     """
-    df = pd.read_csv(Params.DATA_HFI_PATH, index_col=0)
+    with resources.open_binary("tests.data", Params.DATA_HFI_PATH) as file:
+        file = file.read()
+        file = io.BytesIO(file)
+    df = pd.read_csv(file, index_col=0)
     df.index = pd.to_datetime(df.index).to_period("M")
     df /= 100
     return df
